"use strict";
/**
 * Modal
 * Dependencies:
 * - @gorhom/bottom-sheet.
 *
 * Props:
 * - All `BottomSheetModalProps` props.
 * - `title` (string | undefined): Optional title for the modal header.
 *
 * Usage Example:
 * import { Modal, useModal } from '@gorhom/bottom-sheet';
 *
 * function DisplayModal() {
 *   const { ref, present, dismiss } = useModal();
 *
 *   return (
 *     <View>
 *       <Modal
 *         snapPoints={['60%']} // optional
 *         title="Modal Title"
 *         ref={ref}
 *       >
 *         Modal Content
 *       </Modal>
 *     </View>
 *   );
 * }
 *
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderBackdrop = exports.Modal = exports.useModal = void 0;
var bottom_sheet_1 = require("@gorhom/bottom-sheet");
var React = __importStar(require("react"));
var react_native_1 = require("react-native");
var react_native_reanimated_1 = __importStar(require("react-native-reanimated"));
var react_native_svg_1 = require("react-native-svg");
var text_1 = require("./text");
var useModal = function () {
    var ref = React.useRef(null);
    var present = React.useCallback(function (data) {
        var _a;
        (_a = ref.current) === null || _a === void 0 ? void 0 : _a.present(data);
    }, []);
    var dismiss = React.useCallback(function () {
        var _a;
        (_a = ref.current) === null || _a === void 0 ? void 0 : _a.dismiss();
    }, []);
    return { ref: ref, present: present, dismiss: dismiss };
};
exports.useModal = useModal;
exports.Modal = React.forwardRef(function (_a, ref) {
    var _b = _a.snapPoints, _snapPoints = _b === void 0 ? ['60%'] : _b, title = _a.title, _c = _a.detached, detached = _c === void 0 ? false : _c, props = __rest(_a, ["snapPoints", "title", "detached"]);
    var detachedProps = React.useMemo(function () { return getDetachedProps(detached); }, [detached]);
    var modal = (0, exports.useModal)();
    var snapPoints = React.useMemo(function () { return _snapPoints; }, [_snapPoints]);
    React.useImperativeHandle(ref, function () { return modal.ref.current || null; });
    var renderHandleComponent = React.useCallback(function () { return (<>
          <react_native_1.View className="mb-8 mt-2 h-1 w-12 self-center rounded-lg bg-gray-400 dark:bg-gray-700"/>
          <ModalHeader title={title} dismiss={modal.dismiss}/>
        </>); }, [title, modal.dismiss]);
    return (<bottom_sheet_1.BottomSheetModal {...props} {...detachedProps} ref={modal.ref} index={0} snapPoints={snapPoints} backdropComponent={props.backdropComponent || exports.renderBackdrop} enableDynamicSizing={false} handleComponent={renderHandleComponent}/>);
});
/**
 * Custom Backdrop
 */
var AnimatedPressable = react_native_reanimated_1.default.createAnimatedComponent(react_native_1.Pressable);
var CustomBackdrop = function (_a) {
    var style = _a.style;
    var close = (0, bottom_sheet_1.useBottomSheet)().close;
    return (<AnimatedPressable onPress={function () { return close(); }} entering={react_native_reanimated_1.FadeIn.duration(50)} exiting={react_native_reanimated_1.FadeOut.duration(20)} style={[style, { backgroundColor: 'rgba(0, 0, 0, 0.4)' }]}/>);
};
var renderBackdrop = function (props) { return (<CustomBackdrop {...props}/>); };
exports.renderBackdrop = renderBackdrop;
/**
 *
 * @param detached
 * @returns
 *
 * @description
 * In case the modal is detached, we need to add some extra props to the modal to make it look like a detached modal.
 */
var getDetachedProps = function (detached) {
    if (detached) {
        return {
            detached: true,
            bottomInset: 46,
            style: { marginHorizontal: 16, overflow: 'hidden' },
        };
    }
    return {};
};
/**
 * ModalHeader
 */
var ModalHeader = React.memo(function (_a) {
    var title = _a.title, dismiss = _a.dismiss;
    return (<>
      {title && (<react_native_1.View className="flex-row px-2 py-4">
          <react_native_1.View className="size-[24px]"/>
          <react_native_1.View className="flex-1">
            <text_1.Text className="text-center text-[16px] font-bold text-[#26313D] dark:text-white">
              {title}
            </text_1.Text>
          </react_native_1.View>
        </react_native_1.View>)}
      <CloseButton close={dismiss}/>
    </>);
});
var CloseButton = function (_a) {
    var close = _a.close;
    return (<react_native_1.Pressable onPress={close} className="absolute right-3 top-3 size-[24px] items-center justify-center " hitSlop={{ top: 20, bottom: 20, left: 20, right: 20 }} accessibilityLabel="close modal" accessibilityRole="button" accessibilityHint="closes the modal">
      <react_native_svg_1.Svg className="fill-neutral-300 dark:fill-white" width={24} height={24} fill="none" viewBox="0 0 24 24">
        <react_native_svg_1.Path d="M18.707 6.707a1 1 0 0 0-1.414-1.414L12 10.586 6.707 5.293a1 1 0 0 0-1.414 1.414L10.586 12l-5.293 5.293a1 1 0 1 0 1.414 1.414L12 13.414l5.293 5.293a1 1 0 0 0 1.414-1.414L13.414 12l5.293-5.293Z"/>
      </react_native_svg_1.Svg>
    </react_native_1.Pressable>);
};
//# sourceMappingURL=modal.js.map