import * as React from 'react';
import type { SvgProps } from 'react-native-svg';
import Svg, { Path } from 'react-native-svg';
import { getColor } from '../style-utils';
import { Animated, Easing } from 'react-native';

type IconSize = '2xsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge';
type AnimationState = 1 | 2 | 3 | 4;

const SIZE_MAP: Record<IconSize, number> = {
  '2xsmall': 12,
  xsmall: 16,
  small: 20,
  medium: 24,
  large: 32,
  xlarge: 40,
};

const ROTATION_MAP: Record<AnimationState, number> = {
  1: 90,
  2: 180,
  3: 270,
  4: 360,
};

interface CustomIndicatorProps extends SvgProps {
  size?: IconSize;
  color?: string;
  state?: AnimationState;
}

const CustomIndicator = ({
  size = '2xsmall',
  color = '#10B981',
  state = 1,
  ...props
}: CustomIndicatorProps) => {
  const dimension = SIZE_MAP[size];
  const rotation = ROTATION_MAP[state];
  const finalColor = getColor(color);

  const spinAnimation = React.useRef(new Animated.Value(0)).current;

  React.useEffect(() => {
    spinAnimation.setValue(0);
    Animated.loop(
      Animated.timing(spinAnimation, {
        toValue: 1,
        duration: 1000,
        easing: Easing.linear,
        useNativeDriver: true,
      }),
    ).start();
  }, []);

  const spin = spinAnimation.interpolate({
    inputRange: [0, 1],
    outputRange: [`${rotation}deg`, `${rotation + 360}deg`],
  });

  const AnimatedSvg = Animated.createAnimatedComponent(Svg);

  return (
    <AnimatedSvg
      width={dimension}
      height={dimension}
      viewBox="0 0 12 12"
      fill="none"
      style={{ transform: [{ rotate: spin }] }}
      {...props}
    >
      <Path
        d="M6 11.55c0 .248.202.452.45.433A5.999 5.999 0 007.17.115 6 6 0 00.018 5.55.425.425 0 00.45 6a.483.483 0 00.47-.45 5.1 5.1 0 115.53 5.53.483.483 0 00-.45.47z"
        fill={finalColor}
      />
    </AnimatedSvg>
  );
};

export default CustomIndicator;
